import { shallowMount, createLocalVue } from "@vue/test-utils";
import Vuex from "vuex";
import PageLayoutForm from "../../../src/components/LayoutBuilderPageLayoutForm.vue";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const localVue = createLocalVue();
const store = Store(state);

localVue.use(Vuex);

describe("PageLayoutForm.vue", () => {
  const action = "foo";

  const wrapper = shallowMount(PageLayoutForm, {
    propsData: {
      indexSection: 2,
      section: {
        layout: null
      }
    },
    store,
    localVue
  });

  const stub = jest.fn();
  store.dispatch = stub;

  it("should render the correct form action", () => {
    expect(wrapper.element.action).toEqual(action);
  });

  it("sets the stringified value of state.sections as the value of the section input", () => {
    expect(
      wrapper.find(".LayoutBuilderPageLayoutForm-input").attributes().value
    ).toEqual(JSON.stringify(store.state.sections));
  });

  describe("submitting the form", () => {
    wrapper.vm.save = stub;

    it("calls save()", () => {
      wrapper.element.dispatchEvent(new Event("submit"));
      expect(stub).toHaveBeenCalled();
    });
  });
});
